function [smiData] = initializeSmiData()
    %% Initialize the structure
    smiData = struct();

    %% Solids
    smiData.Solid = struct();

    %% Granite
    smiData.Solid.granite.density = 2800; % Granite [kg/m3]
    smiData.Solid.granite.color = [1 1 1];
    smiData.Solid.granite.STEP = '.\STEPS\granite\granite.STEP';

    %% Y-Translation
    % Ty Stator Part
    smiData.Solid.ty.stator.density = 5400;
    smiData.Solid.ty.stator.color = [0.792 0.820 0.933];
    smiData.Solid.ty.stator.STEP = './STEPS/ty/Ty_Motor_Stator.STEP';
    % Ty Granite frame
    smiData.Solid.ty.granite_frame.density = 2800;
    smiData.Solid.ty.granite_frame.color = [0.753 1 0.753];
    smiData.Solid.ty.granite_frame.STEP = '.\STEPS\Ty\Ty_Granite_Frame.STEP';
    % Guide Translation Ty
    smiData.Solid.ty.guide.density = 7800;
    smiData.Solid.ty.guide.color = [0.792 0.820 0.933];
    smiData.Solid.ty.guide.STEP = './STEPS/ty/Ty_Guide.STEP';
    % Ty Rotor Part
    smiData.Solid.ty.rotor.density = 7800;
    smiData.Solid.ty.rotor.color = [0.792 0.820 0.933];
    smiData.Solid.ty.rotor.STEP = './STEPS/ty/Ty_Motor_Rotor.STEP';
    % Ty - Guide_Translation12
    smiData.Solid.ty.guide12.density = 1450;
    smiData.Solid.ty.guide12.color = [0.792 0.820 0.933];
    smiData.Solid.ty.guide12.STEP = '.\STEPS\Ty\Ty_Guide_12.STEP';
    % Ty - Guide_Translation11
    smiData.Solid.ty.guide11.density = 1450;
    smiData.Solid.ty.guide11.color = [0.792 0.820 0.933];
    smiData.Solid.ty.guide11.STEP = './STEPS/ty/Ty_Guide_11.STEP';
    % Ty - Guide_Translation22
    smiData.Solid.ty.guide22.density = 1450;
    smiData.Solid.ty.guide22.color = [0.792 0.820 0.933];
    smiData.Solid.ty.guide22.STEP = './STEPS/ty/Ty_Guide_22.STEP';
    % Ty - Guide_Translation21
    smiData.Solid.ty.guide21.density = 1450;
    smiData.Solid.ty.guide21.color = [0.792 0.820 0.933];
    smiData.Solid.ty.guide21.STEP = '.\STEPS\Ty\Ty_Guide_21.STEP';
    % Ty - Plateau translation
    smiData.Solid.ty.frame.density = 7800;
    smiData.Solid.ty.frame.color = [0.792 0.820 0.933];
    smiData.Solid.ty.frame.STEP = '.\STEPS\ty\Ty_Stage.STEP';

    %% Tilt Stage
    % Ry - Guide for the tilt stage
    smiData.Solid.ry.guide.density = 7800;
    smiData.Solid.ry.guide.color = [0.792 0.820 0.933];
    smiData.Solid.ry.guide.STEP = '.\STEPS\ry\Tilt_Guide.STEP';
    % Ry - Plateau Tilt
    smiData.Solid.ry.stage.density = 7800;
    smiData.Solid.ry.stage.color = [0.792 0.820 0.933];
    smiData.Solid.ry.stage.STEP = '.\STEPS\ry\Tilt_Stage.STEP';
    % Ry - Rotor of the motor
    smiData.Solid.ry.rotor.density = 2400;
    smiData.Solid.ry.rotor.color = [0.792 0.820 0.933];
    smiData.Solid.ry.rotor.STEP = '.\STEPS\ry\Tilt_Motor_Axis.STEP';
    % Ry - Motor
    smiData.Solid.ry.motor.density = 3200;
    smiData.Solid.ry.motor.color = [0.792 0.820 0.933];
    smiData.Solid.ry.motor.STEP = '.\STEPS\ry\Tilt_Motor.STEP';

    %% Spindle
    % Spindle - Motor
    smiData.Solid.rz.slipring.density = 7800;
    smiData.Solid.rz.slipring.color = [0.792 0.820 0.933];
    smiData.Solid.rz.slipring.STEP = '.\STEPS\rz\Spindle_Slip_Ring.STEP';
    % Spindle - Rotor
    smiData.Solid.rz.rotor.density = 7800;
    smiData.Solid.rz.rotor.color = [0.792 0.820 0.933];
    smiData.Solid.rz.rotor.STEP = '.\STEPS\rz\Spindle_Rotor.STEP';
    % Spindle - Stator
    smiData.Solid.rz.stator.density = 7800;
    smiData.Solid.rz.stator.color = [0.792 0.820 0.933];
    smiData.Solid.rz.stator.STEP = '.\STEPS\rz\Spindle_Stator.STEP';

    %% Axis Compensator
    % Structure
    smiData.Solid.axisc.structure.density = 3400;
    smiData.Solid.axisc.structure.color = [0.792 0.820 0.933];
    smiData.Solid.axisc.structure.STEP = '.\STEPS\axisc\Disc_Stator.STEP';
    % Wheel
    smiData.Solid.axisc.wheel.density = 2700;
    smiData.Solid.axisc.wheel.color = [0.753 0.753 0.753];
    smiData.Solid.axisc.wheel.STEP = '.\STEPS\axisc\axisc_guidance.STEP';
    % Mass
    smiData.Solid.axisc.masses.density = 7800;
    smiData.Solid.axisc.masses.color = [0.792 0.820 0.933];
    smiData.Solid.axisc.masses.STEP = './STEPS/axisc/Axisc_Mass.STEP';
    % Gear
    smiData.Solid.axisc.gear.density = 7800;
    smiData.Solid.axisc.gear.color = [0.792 0.820 0.933];
    smiData.Solid.axisc.gear.STEP = '.\STEPS\axisc\axisc_gearing.STEP';

    %% Save
    save('./mat/smiData.mat', 'smiData')
end
